/*
	Copyright (C) 2011 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.menu;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.clients.web.extensions.menu.MenuItemAction;
import net.sf.basedb.clients.web.extensions.menu.MenuItemBean;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.SessionControl;
import net.sf.basedb.core.User;
import net.sf.basedb.util.extensions.ClientContext;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.extensions.xml.PathSetter;
import net.sf.basedb.util.extensions.xml.VariableSetter;

/**
	Example menu item factory that creates a "Hello world" menu item
	where the "Hello" part can be changed by the "prefix" setting in the
	XML file, and the "world" part is dynamically replaced with the name
	of the logged in user.
	
	@author nicklas
*/
public class HelloUserFactory 
	extends AbstractJspActionFactory<MenuItemAction>
{
	// The ID attribute of the <div> tag in the final HTML
	private String id;
	
	// To store the URL to the icon
	private String icon;
	
	// The default prefix is Hello
	private String prefix = "Hello";
	
	// A public, no-argument constructor is required
	public HelloUserFactory()
	{}
	
	/**
		Creates a menu item that displays: {prefix} {name of user}!
	*/
	@Override
	public MenuItemAction[] getActions(InvokationContext<? super MenuItemAction> context) 
	{
		String userName = getUserName(context.getClientContext());
		MenuItemBean helloUser = new MenuItemBean();
		helloUser.setId(id);
		helloUser.setMenuId("hello");
		helloUser.setTitle(prefix + " " + userName + "!");
		helloUser.setIcon(icon);
		// Use 'dynamic' attributes for extra info that needs to be included
		// in the HTML
		setParameter("data-user-name", userName);
		setParameter("data-prefix", prefix);
		helloUser.setDynamicActionAttributesSource(this);
		
		return new MenuItemAction[] { helloUser };
	}

	/**
		Get the name of the logged in user.
	*/
	private String getUserName(ClientContext context)
	{
		SessionControl sc = context.getSessionControl();
		DbControl dc = context.getDbControl();
		User current = User.getById(dc, sc.getLoggedInUserId());
		return current.getName();
	}
	
	/**
		Set the ID to use for the <div> tag. This is needed
		so that we can attach a 'click' handler to the menu item
		with JavaScript (see examples.jsp)
	*/
	public void setId(String id)
	{
		this.id = id;
	}
	
	/**
		Sets the icon to use. Path conversion is enabled.
	*/
	@VariableSetter
	@PathSetter
	public void setIcon(String icon)
	{
		this.icon = icon;
	}
	
	/**
		Sets the prefix to use. If not set, the
		default value is "Hello".
	*/
	public void setPrefix(String prefix)
	{
		this.prefix = prefix == null ? "Hello" : prefix;
	}
}
