/*
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.overview;

import net.sf.basedb.clients.web.extensions.section.IncludeContentSectionFactory;
import net.sf.basedb.clients.web.extensions.section.SectionAction;
import net.sf.basedb.core.Nameable;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.overview.Node;

/**
	Example action factory that create an action that adds a section
	to the item overview information. The factory is based on the
	{@link IncludeContentSectionFactory} shipped with BASE, but adds
	a check that disabled the extension for nodes that doesn't
	contain a {@link Nameable} item. The content of the section is generated
	by the <code>overview_info.jsp</code> (as it is configured in the
	META-INF/extensions.xml file).
	
	@author Nicklas
	@since 1.5
*/
public class InfoSectionFactory 
	extends IncludeContentSectionFactory 
{

	public InfoSectionFactory()
	{}
	
	@Override
	public boolean prepareContext(InvokationContext<? super SectionAction> context) 
	{
		// Get the currently selected node
		Node node = (Node)context.getClientContext().getCurrentItem();
		// Disable the extension if the node doesn't represent a Nameable item
		if (!(node.getItem() instanceof Nameable)) return false;
		// The extension should be enabled -- let the superclass continue
		return super.prepareContext(context);
	}

}
