/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.overview;


import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Role;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.Severity;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.extensions.NodeValidatorAction;
import net.sf.basedb.util.overview.validator.NameableNodeValidator;

/**
	Validator implementation that check role membership of a user.
	We extend from the {@link NameableNodeValidator} / {@link BasicNodeValidator} 
	class to be able to take advantage of already implemented functionality in the BASE core.
	The rules we check for in this validator are:
	<ul>
	<li>No role membership: {@link #MISSING_ROLE}
	</ul>
	
	@author Nicklas
	@since 1.5
*/
public class RoleValidator
	extends NameableNodeValidator<Role>
	implements NodeValidatorAction<Role>
{

	/**
		Validation rule definition for missing role membership.
		Default severity level is WARNING.
	*/
	public static Validator MISSING_ROLE = new Validator("missing.role", "Missing role",
		"Checks if a user is a member of at least one role.", "Missing role", 
		Severity.WARNING);
	
	
	public RoleValidator()
	{
		super(null, null);
	}

	/*
		From the NodeValidator interface
		--------------------------------
	*/


	/**
		@return Always null
	*/
	@Override
	protected Fix getMissingItemFix(DbControl dc, Node parentNode)
	{
		return null;
	}

	@Override
	public void postValidateFolder(DbControl dc, OverviewContext context, Node folderNode, Node parentNode)
	{
		super.postValidateFolder(dc, context, folderNode, parentNode);
		
		if (folderNode == null || folderNode.numChildren() == 0)
		{
			// The user is not member of any roles
			context.createFailure(MISSING_ROLE, parentNode, null, new Fix("Add roles to the user", parentNode.getItem()));
		}
	}
	
}
