/*
	Copyright (C) 2011 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.toolbar;

import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.clients.web.extensions.toolbar.ButtonAction;
import net.sf.basedb.clients.web.extensions.toolbar.ButtonBean;
import net.sf.basedb.clients.web.extensions.toolbar.FixedButtonFactory;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.Nameable;
import net.sf.basedb.core.data.BasicData;
import net.sf.basedb.core.data.NameableData;
import net.sf.basedb.core.plugin.GuiContext;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Example toolbar button factory that creates a "More info" button
	on all single-item pages that opens a dialog that displays some
	trivial information about the item.
	<p>
	This factory builds on the {@link FixedButtonFactory}
	but uses a simple template patten in the {@link #getOnClick()} 
	($TYPE and $ID are replaced
	with the item type and item id) and {@link #getTooltip()}
	($NAME is replaced by the name of the item).
	
	@author nicklas
*/
public class InfoButtonFactory 
	extends FixedButtonFactory
{

	public InfoButtonFactory()
	{}
	
	@Override
	public ButtonAction[] getActions(InvokationContext context) 
	{
		ButtonAction[] actions = null;
		Object item = context.getClientContext().getCurrentItem();
		JspContext jspContext = (JspContext)context.getClientContext();
		GuiContext guiContext = jspContext.getGuiContext();
		String ID = null;
		String TYPE = guiContext == null ? null : guiContext.getItem().name();
		String name = null;
		if (item instanceof BasicItem)
		{
			BasicItem bItem = (BasicItem)item;
			ID = Integer.toString(bItem.getId());
			TYPE = bItem.getType().name();
			name = (item instanceof Nameable) ?
				((Nameable)item).getName() : item.toString();
				
		}
		else if (item instanceof BasicData)
		{
			BasicData bData = (BasicData)item;
			ID = Integer.toString(bData.getId());
			name = (item instanceof NameableData) ?
					((NameableData)item).getName() : item.toString();
		}
		String tooltip = getTooltip();
		if (tooltip != null)
		{
			if (name != null) tooltip = tooltip.replace("$NAME", name);
		}
		ButtonBean action = new ButtonBean();
		action.setClazz(getClazz());
		action.setEnabled(isEnabled());
		action.setIcon(getIcon());
		action.setId(getId());
		action.setStyle(getStyle());
		action.setTitle(getTitle());
		action.setTooltip(tooltip);
		action.setVisible(isVisible());
		
		// We use dynamic attributes to store TYPE and ID of current item
		if (TYPE != null) setParameter("data-item-type", TYPE);
		if (ID != null) setParameter("data-item-id", ID);
		action.setDynamicActionAttributesSource(this);

		actions = new ButtonAction[] { action };
		return actions;
	}

}
